==========================================================
API documentation for interacting with the Galaxy Toolshed
==========================================================

ToolShedInstance
----------------

.. autoclass:: bioblend.toolshed.ToolShedInstance

    .. automethod:: bioblend.toolshed.ToolShedInstance.__init__


Categories
----------

.. automodule:: bioblend.toolshed.categories

Repositories
------------

.. automodule:: bioblend.toolshed.repositories

Tools
-----

.. automodule:: bioblend.toolshed.tools
